angular.module('ionic.weather', ['ionic', 'ionic.weather.services', 'ionic.weather.filters', 'ionic.weather.directives', 'ngTouch'])

.constant('FORECASTIO_KEY', 'f46fea7abe0e4e219bc09bcb69997e0c')
.constant('FLICKR_API_KEY', 'bd4aa177a00d45348292465e0d962079')

.controller('WeatherCtrl', function($scope, $timeout, $rootScope, Weather, Geo, Flickr, $ionicModal, $ionicPlatform, Settings) {
  var _this = this;

  $scope.activeBgImageIndex = 0
  $scope.time = new Date().getTime()
  
  $scope.swipeLeft = function()
  {
	if($scope.bgImages)
	{
		$scope.activeBgImageIndex++
		$scope.activeBgImage = $scope.bgImages[$scope.activeBgImageIndex % $scope.bgImages.length]
    }
  }
  
  $scope.swipeRight = function()
  {
	if($scope.bgImages)
	{
		$scope.activeBgImageIndex--
		$scope.activeBgImage = $scope.bgImages[$scope.activeBgImageIndex % $scope.bgImages.length]
    }
  }

  $scope.showSettings = function() {
    if(!$scope.settingsModal) {
      $ionicModal.fromTemplateUrl('settings.html', function(modal) {
        $scope.settingsModal = modal;
        $scope.settingsModal.show();
      }, {
        animation:'slide-in-up'
      });
    } else {
      $scope.settingsModal.show();
    }
  };

  this.getBackgroundImage = function(lat, lng, locString) {
    Flickr.search(locString, lat, lng).then(function(resp) {
      var photos = resp.photos;
      if(photos.photo.length)
      {
        $scope.bgImages = photos.photo
		shuffle($scope.bgImages)
		_this.cycleBgImages()
      }
      else
      {
        $scope.activeBgImage="nothing"
      }
    }, function(error){}
	);
  };

  $rootScope.$on('settings.changed', function(settings) {
		$scope.settings = Settings.getSettings();
		$scope.current.units = $scope.settings.tempUnits
	});
  
  this.getCurrent = function(lat, lng, locString) {
    Weather.getAtLocation(lat, lng).then(function(resp) {
      $scope.current = resp.data;
	  $scope.settings = Settings.getSettings();
	  $scope.current.units = $scope.settings.tempUnits
      $rootScope.$broadcast('scroll.refreshComplete');
    }, function(error) {
      alert('Unable to get current conditions');
    });
  };
  
	function shuffle(sourceArray)
	{
		for (var n = 0; n < sourceArray.length - 1; n++)
		{
			var k = n + Math.floor(Math.random() * (sourceArray.length - n));
			var temp = sourceArray[k];
			sourceArray[k] = sourceArray[n];
			sourceArray[n] = temp;
		}
	}
  
  $scope.showNextImage = function(){
	if($scope.bgImages) {
		$scope.activeBgImageIndex++
		$scope.activeBgImage = $scope.bgImages[$scope.activeBgImageIndex % $scope.bgImages.length];
		$scope.$apply()
	}
  }
  
  this.cycleBgImages = function() {
	if(!$scope.bgCycle)
	{
		$scope.bgCycle = setInterval($scope.showNextImage, 15000)
	}
	if($scope.bgImages)
	{
		$scope.activeBgImageIndex++
		$scope.activeBgImage = $scope.bgImages[$scope.activeBgImageIndex % $scope.bgImages.length];
	}
  };
  
  
  $scope.refreshData = function(){
	var options = {
		enableHighAccuracy:true,
		timeout:7000,
		maximumAge:0
	};

	navigator.geolocation.getCurrentPosition(function success(pos) {
		var crd = pos.coords
		var lat = crd.latitude
		var lng = crd.longitude
		Geo.reverseGeocode(lat, lng).then(function(locString) {
			$scope.currentLocationString = locString;
			_this.getBackgroundImage(lat, lng, locString);
		});
		_this.getCurrent(lat, lng);
		$scope.$apply()
	}, null, options);
  };

  $scope.refreshData();

  setInterval($scope.refreshData, 1800000) //auto refresh once per half hour
})

.controller('SettingsCtrl', function($scope, $timeout, $rootScope, Weather, Geo, Flickr, $ionicModal, $ionicPlatform, Settings) {
  $scope.settings = Settings.getSettings();

  $scope.$watch('settings', function(v) {
    Settings.save();
  }, true);

  if($scope.settings.tempUnits == 'c')
  {
	$scope.buttonText = 'Switch to Fahrenheit';
  }
  else
  {
	$scope.buttonText = 'Switch to Celsius';
  }
  
  $scope.radioChange = function()
  {
	if($scope.settings.tempUnits == 'f')
	{
		$scope.settings.tempUnits = 'c'
		$scope.buttonText="Switch to Fahrenheit"
	}
	else
	{
		$scope.settings.tempUnits = 'f'
		$scope.buttonText="Switch to Celsius"
	}
	$scope.$apply()
  };
  
  $scope.launchWebsite = function(url)
  {
    window.open(url, '_blank', 'location=yes');
  }

  $scope.closeSettings = function() {
    $scope.modal.hide();
  };

});
